colour.colorimetry.dataset Package — Colour 0.3.0 documentation

# colour.colorimetry.dataset Package

## Sub-Packages

- colour.colorimetry.dataset.illuminants Package
  - Sub-Modules
    - colour.colorimetry.dataset.illuminants.chromaticity_coordinates Module
      - Illuminants Chromaticity Coordinates
    - colour.colorimetry.dataset.illuminants.d_illuminants_s_spds Module
      - CIE Standard Illuminant D Series \(S_n(\lambda)\) Spectral Power Distributions
    - colour.colorimetry.dataset.illuminants.spds Module
      - Illuminants Relative Spectral Power Distributions
  - Module Contents

## Sub-Modules

- colour.colorimetry.dataset.cmfs Module
  - Colour Matching Functions Spectral Power Distributions
- colour.colorimetry.dataset.lefs Module
  - Luminous Efficiency Functions Spectral Power Distributions

## Module Contents